@@ -5,7 +5,7 @@ use warnings;
 use Carp;
 use vars qw/$VERSION $AUTOLOAD/;
 
-our $VERSION = '1.08';
+our $VERSION = '1.11';
 
 =head1 NAME
 
@@ -295,7 +295,7 @@ characters escaped if this option is supplied.  If the value is 'always',
 then &, < and > (and " within attribute values) will be converted into
 the corresponding XML entity, although & will not be converted if it looks
 like it could be part of a valid entity (but see below).  If the value is
-'unescaped', then the escaping will be turned off character-by- character
+'unescaped', then the escaping will be turned off character-by-character
 if the character in question is preceded by a backslash, or for the
 entire string if it is supplied as a scalar reference.  So, for example,
 
@@ -303,7 +303,7 @@ entire string if it is supplied as a scalar reference.  So, for example,
 
 	one('<');      # <one>&lt;</one>
 	two('\&');     # <two>\&amp;</two>
-	three(\'>');   # <three>&gt;</three> (scalar refs always allowed)
+	three(\'<f>'); # <three><f></three> (scalar refs always allowed)
 	four('&lt;');  # <four>&lt;</four> (looks like an entity)
 	five('&#34;'); # <five>&#34;</five> (looks like an entity)
 
@@ -313,7 +313,7 @@ but
 
 	one('<');     # <one>&lt;</one>
 	two('\&');    # <two>&</two>
-	three(\'>');  # <three>></three> (aiee!)
+	three(\'<f>');# <three><f></three>  (scalar refs always allowed)
 	four('&lt;'); # <four>&amp;lt;</four> (no special case for entities)
 
 By default, high-bit data will be passed through unmodified, so that
@@ -435,6 +435,12 @@ Sets the default encoding for use in XML declarations.
 Specify the dtd.  The value should be an array reference with three
 values; the type, the name and the uri.
 
+=head2 xml
+
+This is an hash ref value that should contain the version, encoding and dtd
+values (same as above). This is used in case C<conformance> is set to C<loose>,
+but you still want to use the xml declaration or prolog.
+
 =head1 IMPORT ARGUMENTS
 
 use XML::Generator ':option';
@@ -620,6 +626,10 @@ sub new {
     $options{'escape'} = 0;
   }
 
+  if ($options{'xml'} && ref $options{'xml'} ne 'HASH') {
+      Carp::croak("XML arguments must be a hash");
+  }
+
   if (ref $options{'namespace'} eq 'ARRAY') {
     if (@{ $options{'namespace'} } > 2 && (@{ $options{'namespace'} } % 2) != 0) {
       Carp::croak "odd number of arguments for namespace";
@@ -768,23 +778,38 @@ explicitly provide undef as the value.
 
 =cut
 
+sub _allow_xml_cmd {
+    my $this = shift;
+    return 1 if $this->{conformance} eq 'strict';
+    return 1 if defined $this->{xml};
+    return 0;
+}
+
+
 sub xmldecl {
-  my($this, @args) = @_;
+  my $this = shift;
 
-  return $this->XML::Generator::util::tag('xmldecl', @_)
-		unless $this->{conformance} eq 'strict';
+  return $this->XML::Generator::util::tag('xmldecl', @_) unless $this->{conformance} eq 'strict';
+  return $this->_xmldecl(@_);
+}
 
-  my $version  = $this->{'version'} || '1.0';
+sub _xmldecl {
+  my $this = shift;
+  my @args = @_;
+
+  return unless $this->_allow_xml_cmd;
+
+  my $version  = $this->{xml}{version} // $this->{'version'} || '1.0';
 
   # there's no explicit support for encodings yet, but at the
   # least we can know to put it in the declaration
-  my $encoding = $this->{'encoding'};
+  my $encoding = $this->{xml}{encoding} // $this->{'encoding'};
 
   # similarly, although we don't do anything with DTDs yet, we
   # recognize a 'dtd' => [ ... ] option to the constructor, and
   # use it to create a <!DOCTYPE ...> and to indicate that this
   # document can't stand alone.
-  my $doctype = $this->xmldtd($this->{dtd});
+  my $doctype = $this->xmldtd($this->{xml}{dtd} // $this->{dtd});
   my $standalone = $doctype ? "no" : "yes";
 
   for (my $i = 0; $i < $#args; $i += 2) {
@@ -807,12 +832,9 @@ sub xmldecl {
   $version    ||= '';
   $standalone ||= '';
 
-  my $xml = "<?xml$version$encoding$standalone?>";
-  $xml .= "\n$doctype" if $doctype;
-
-  $xml = "$xml\n";
-
-  return $xml;
+  my @xml = ("<?xml$version$encoding$standalone?>");
+  push(@xml, $doctype) if $doctype;
+  return join("\n", @xml, "");
 }
 
 =head2 xmldtd
@@ -883,7 +905,7 @@ sub xml {
   my $this = shift;
 
   return $this->XML::Generator::util::tag('xml', @_)
-		unless $this->{conformance} eq 'strict';
+        unless $this->_allow_xml_cmd;
 
   unless (@_) {
     Carp::croak "usage: object->xml( (COMMENT | PI)* XML (COMMENT | PI)* )";
@@ -903,7 +925,7 @@ sub xml {
     }
   }
 
-  return XML::Generator::final->new([$this->xmldecl(), @_]);
+  return XML::Generator::final->new([$this->_xmldecl(), @_]);
 }
 
 =head1 CREATING A SUBCLASS
